/*
 * Copyright (C) 2002-2003 Stefan Stiller
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.kiwisoft.db;

import java.sql.Blob;
import java.sql.Clob;
import java.sql.SQLException;
import java.lang.reflect.Method;

/**
 * @author Stefan Stiller
 * @version $Revision: 1.2 $, $Date: 2004/11/21 11:16:19 $
 */
public class DataConverter
{
	private static Class ORACLE_DATUM;

	static
	{
		try
		{
			ORACLE_DATUM=Class.forName("oracle.sql.Datum");
		}
		catch (Throwable e)
		{
		}
	}

	private DataConverter()
	{
	}

	public static Class convertClass(Class aClass)
	{
		if (aClass==null) return null;
		if (byte[].class==aClass) return String.class;
		if (Blob.class.isAssignableFrom(aClass)) return BLOBWrapper.class;
		if (Clob.class.isAssignableFrom(aClass)) return CLOBWrapper.class;
		if (ORACLE_DATUM!=null && ORACLE_DATUM.isAssignableFrom(aClass))
		{
			return null;
		}
		return aClass;
	}

	public static Object convertValue(Object value, ClassLoader classLoader, boolean loadLOBs) throws SQLException
	{
		if (value!=null)
		{
			if (value instanceof byte[]) return new String((byte[])value);
			if (value instanceof Blob) return new BLOBWrapper((Blob)value, classLoader, loadLOBs);
			if (value instanceof Clob) return new CLOBWrapper((Clob)value, loadLOBs);
			if (ORACLE_DATUM!=null && ORACLE_DATUM.isInstance(value))
			{
				try
				{
					Method method=ORACLE_DATUM.getDeclaredMethod("toJdbc", null);
					return method.invoke(value, null);
				}
				catch (Throwable e)
				{
					return value;
				}
			}
		}
		return value;
	}

}
