/*
 * Copyright (C) 2002-2003 Stefan Stiller
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.kiwisoft.db;

import java.util.Collection;
import java.sql.SQLException;

import com.kiwisoft.utils.PropertyHolder;
import com.intellij.openapi.project.Project;

/**
 * @author Stefan Stiller
 * @version $Revision: 1.1 $, $Date: 2004/07/21 20:37:59 $
 */
public class DatabaseSchema implements PropertyHolder
{
	private Database database;

	private final static String NAME="Name";
	private final static String CATALOG="Catalog";

	private String schemaName;
	private String catalog;

	public DatabaseSchema(Database database, String schemaName, String catalog)
	{
		this.database=database;
		this.schemaName=schemaName;
		this.catalog=catalog;
	}

	public Database getDatabase()
	{
		return database;
	}

	public String getCatalog()
	{
		return catalog;
	}

	public String getName()
	{
		if (schemaName!=null)
			return schemaName;
		else
			return "Default Schema";
	}

	public String getSchemaName()
	{
		return schemaName;
	}

	public Collection getTables(Project project, String tableType) throws Exception
	{
		return database.getTables(project, this, tableType);
	}

	public Collection getProcedures(Project project) throws SQLException
	{
		return database.getProcecures(project, this);
	}

	public String[] getPropertyNames()
	{
		return new String[]{
			NAME, CATALOG
		};
	}

	public Object getProperty(Project project, String propertyName)
	{
		if (propertyName==NAME) return schemaName;
		if (propertyName==CATALOG) return catalog;
		return null;
	}
}
