/*
 * Copyright (C) 2002-2003 Stefan Stiller
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.kiwisoft.db;

import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.Types;
import java.sql.SQLException;

import javax.swing.JOptionPane;

import com.intellij.openapi.project.Project;
import com.kiwisoft.sqlPlugin.PasswordDialogStub;
import com.kiwisoft.utils.Utils;

/**
 * @author Stefan Stiller
 * @version $Revision: 1.1 $, $Date: 2004/07/21 20:37:59 $
 */
public class DatabaseUtils
{
	private DatabaseUtils()
	{
	}

	public static Connection connect(Project project, Database database)
	{
		if (database==null) throw new RuntimeException("No database specified.");
		Connection connection;
		if (database.isPasswordSet())
		{
			try
			{
				connection=database.connect(database.getPassword());
				return connection;
			}
			catch (SQLException e)
			{
				if (!database.getDatabaseDriver().isPasswordFailure(e))
				{
					System.err.println("SQLException: Error Code="+e.getErrorCode());
					e.printStackTrace();
					database.setPasswordSet(false);
					JOptionPane.showMessageDialog(null, e.getMessage(), "Error", JOptionPane.ERROR_MESSAGE);
					return null;
				}
				else
				{
					database.setPasswordSet(false);
					JOptionPane.showMessageDialog(null, "Access Denied", "Error", JOptionPane.ERROR_MESSAGE);
				}
			}
			catch (Exception e)
			{
				e.printStackTrace();
				JOptionPane.showMessageDialog(null, e.getMessage(), "Error", JOptionPane.ERROR_MESSAGE);
				return null;
			}
		}
		while (true)
		{
			try
			{
				PasswordDialogStub dialogStub=new PasswordDialogStub(database.getName());
				Utils.wrapDialog(project, dialogStub, true, true);
				if (dialogStub.getReturnValue())
				{
					String password=dialogStub.getPassword();
					connection=database.connect(password);
					database.setPassword(password);
					return connection;
				}
				else return null;
			}
			catch (SQLException e)
			{
				if (!database.getDatabaseDriver().isPasswordFailure(e))
				{
					System.err.println("SQLException: Error Code="+e.getErrorCode());
					e.printStackTrace();
					database.setPasswordSet(false);
					JOptionPane.showMessageDialog(null, e.getMessage(), "Error", JOptionPane.ERROR_MESSAGE);
					return null;
				}
				else
				{
					database.setPasswordSet(false);
					JOptionPane.showMessageDialog(null, "Access Denied", "Error", JOptionPane.ERROR_MESSAGE);
				}
			}
			catch (Exception e)
			{
				e.printStackTrace();
				JOptionPane.showMessageDialog(null, e.getMessage(), "Error", JOptionPane.ERROR_MESSAGE);
				return null;
			}
		}
	}

	public static String transactionIsolation(int value)
	{
		switch (value)
		{
			case Connection.TRANSACTION_READ_UNCOMMITTED:
				return "read uncommited";
			case Connection.TRANSACTION_READ_COMMITTED:
				return "read commited";
			case Connection.TRANSACTION_REPEATABLE_READ:
				return "repeatable read";
			case Connection.TRANSACTION_SERIALIZABLE:
				return "transaction serializable";
			case Connection.TRANSACTION_NONE:
				return "none";
		}
		return null;
	}

	public static Object holdability(int holdability)
	{
		switch (holdability)
		{
			case ResultSet.CLOSE_CURSORS_AT_COMMIT:
				return "close cursors at commit";
			case ResultSet.HOLD_CURSORS_OVER_COMMIT:
				return "hold cursors over commit";
		}
		return null;
	}

	public static String getTypeString(int type)
	{
		switch (type)
		{
			case Types.DISTINCT:
				return "DISTINCT";
			case Types.ARRAY:
				return "ARRAY";
			case Types.LONGVARCHAR:
				return "LONGVARCHAR";
			case Types.BLOB:
				return "BLOB";
			case Types.DOUBLE:
				return "DOUBLE";
			case Types.CHAR:
				return "CHAR";
			case Types.FLOAT:
				return "FLOAT";
			case Types.REF:
				return "REF";
			case Types.JAVA_OBJECT:
				return "JAVA_OBJECT";
			case Types.BIT:
				return "BIT";
			case Types.DECIMAL:
				return "DECIMAL";
			case Types.VARCHAR:
				return "VARCHAR";
			case Types.BINARY:
				return "BINARY";
			case Types.OTHER:
				return "OTHER";
			case Types.TIME:
				return "TIME";
			case Types.INTEGER:
				return "INTEGER";
			case Types.CLOB:
				return "CLOB";
			case Types.BOOLEAN:
				return "BOOLEAN";
			case Types.TIMESTAMP:
				return "TIMESTAMP";
			case Types.SMALLINT:
				return "SMALLINT";
			case Types.VARBINARY:
				return "VARBINARY";
			case Types.BIGINT:
				return "BIGINT";
			case Types.TINYINT:
				return "TINYINT";
			case Types.STRUCT:
				return "STRUCT";
			case Types.DATE:
				return "DATE";
			case Types.NULL:
				return "NULL";
			case Types.LONGVARBINARY:
				return "LONGVARBINARY";
			case Types.DATALINK:
				return "DATALINK";
			case Types.NUMERIC:
				return "NUMERIC";
			case Types.REAL:
				return "REAL";
		}
		return "<Unknown>";
	}
}
