package com.kiwisoft.db;

import java.sql.DatabaseMetaData;

import com.intellij.openapi.project.Project;

import com.kiwisoft.utils.PropertyHolder;

/**
 * Created by IntelliJ IDEA.
 * User: Stefan1
 * Date: 06.04.2005
 * Time: 20:26:36
 * To change this template use File | Settings | File Templates.
 */
public abstract class TableKey implements PropertyHolder
{
	protected static final String NAME = "Name";
	protected static final String REFERENCE = "Reference";
	protected static final String UPDATE_RULE = "Update Rule";
	protected static final String DELETE_RULE = "Delete Rule";
	protected static final String DEFERRABILITY = "Deferrability";

	private DatabaseTable table;

	private String name;
	private short updateRule;
	private short deleteRule;
	private short deferrability;

	protected TableKey(DatabaseTable table, String keyName)
	{
		this.table=table;
		this.name=keyName;
	}

	public DatabaseTable getTable()
	{
		return table;
}

	public String getName()
	{
		return name;
	}

	public void setUpdateRule(short updateRule)
	{
		this.updateRule=updateRule;
	}

	public void setDeleteRule(short deleteRule)
	{
		this.deleteRule=deleteRule;
	}

	public void setDeferrability(short deferrability)
	{
		this.deferrability=deferrability;
	}

	public abstract String getReference();

	public Object getProperty(Project project, String propertyName) throws Exception
	{
		if (NAME.equals(propertyName)) return name;
		if (UPDATE_RULE.equals(propertyName))
		{
			switch (updateRule)
			{
				case DatabaseMetaData.importedKeyNoAction:
				case DatabaseMetaData.importedKeyRestrict:
					return "Not Allowed";
				case DatabaseMetaData.importedKeyCascade:
					return "Cascade";
				case DatabaseMetaData.importedKeySetNull:
					return "Set to NULL";
				case DatabaseMetaData.importedKeySetDefault:
					return "Set to Default";
				default:
					return "Unknown";
			}
		}
		if (DELETE_RULE.equals(propertyName))
		{
			switch(deleteRule)
			{
				case DatabaseMetaData.importedKeyNoAction:
				case DatabaseMetaData.importedKeyRestrict:
					return "Not Allowed";
				case DatabaseMetaData.importedKeyCascade:
					return "Cascade";
				case DatabaseMetaData.importedKeySetNull:
					return "Set to NULL";
				case DatabaseMetaData.importedKeySetDefault:
					return "Set to Default";
				default:
					return "Unknown";
			}
		}
		if (DEFERRABILITY.equals(propertyName))
		{
			switch (deferrability)
			{
				case DatabaseMetaData.importedKeyInitiallyDeferred:
					return "Initially Deferred";
				case DatabaseMetaData.importedKeyInitiallyImmediate:
					return "Initially Immediate";
				case DatabaseMetaData.importedKeyNotDeferrable:
					return "Not Deferrable";
			}
		}
		return null;
	}

}
