/*
 * Copyright (C) 2002-2003 Stefan Stiller
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.kiwisoft.db.driver;

import java.util.LinkedList;
import java.util.List;
import java.util.Properties;

import com.kiwisoft.db.*;

/**
 * @author Stefan Stiller, Sergey Bervinov
 * @version $Revision: 1.1 $, $Date: 2004/07/21 20:37:40 $
 */
public class HSQLDBDriver extends DatabaseDriver
{
	public static final String SERVER="Server";
	public static final String WEBSERVER="WebServer";

	public static final DriverProperty TYPE=new ChoiceProperty("type", "Type",
			new String[]{SERVER, WEBSERVER, "Standalone"}, SERVER);
	public static final DriverProperty PORT=new IntegerProperty("port", "Port", new Integer(9001));
	public static final DriverProperty NAME=new StringProperty("name", "Name");
	public static final DriverProperty COLUMN_NAMES=new BooleanProperty("jdbc.get_column_name", "Column Names", Boolean.TRUE);

    public HSQLDBDriver()
    {
		super(new String[]{"org.hsqldb.jdbcDriver"});
    }

    public String getId()
    {
        return "jdbc:hsqldb";
    }

    public String getName()
    {
        return "HSQLDB";
    }

	public List getDriverProperties()
	{
		List list=new LinkedList();
		list.add(TYPE);
		list.add(HOST);
		list.add(PORT);
		list.add(NAME);
		list.add(USER);
		list.add(COLUMN_NAMES);
		list.add(AUTO_COMMIT);
		return list;
	}

	public boolean isRequired(DriverProperty property)
	{
		return property==TYPE || property==USER;
	}

    public String buildURL(DriverProperties map)
    {
        StringBuffer url=new StringBuffer("jdbc:hsqldb:");
		Object type=map.getProperty(TYPE);
		if (SERVER.equals(type))
		{
			url.append("hsql://");
			appendHostAndPot(map, url);
		}
		else if (WEBSERVER.equals(type))
		{
			url.append("http://");
			appendHostAndPot(map, url);
		}
		else
		{
			Object name=map.getProperty(NAME);
			if (name!=null) url.append(name);
		}
        return url.toString();
    }

	private void appendHostAndPot(DriverProperties map, StringBuffer url)
	{
		Object host=map.getProperty(HOST);
		if (host!=null) url.append(host);
		Object port=map.getProperty(PORT);
		if (port!=null) url.append(":"+port);
	}

	public Properties getConnectProperties(DriverProperties map)
	{
		Properties properties=new Properties();
		copyProperty(map, properties, COLUMN_NAMES);
		return properties;
	}
}
