/*
 * Copyright (C) 2002-2003 Stefan Stiller
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.kiwisoft.db.export;

import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.awt.Component;
import javax.swing.JTable;
import javax.swing.JLabel;
import javax.swing.SwingConstants;
import javax.swing.table.TableColumn;
import javax.swing.table.TableColumnModel;
import javax.swing.table.TableCellRenderer;

import com.kiwisoft.sqlPlugin.ResultSetTableModel;
import com.kiwisoft.sqlPlugin.config.ExportConfiguration;
import com.kiwisoft.db.sql.SQLStatement;

/**
 * @author Stefan Stiller
 * @version $Revision: 1.5 $, $Date: 2004/10/26 17:50:11 $
 */
public abstract class AbstractExporter implements Exporter
{
	public boolean isEnabled()
	{
		return true;
	}

	public void exportTable(JTable table, SQLStatement statement, File file, ExportConfiguration configuration) throws IOException
    {
        PrintWriter out=new PrintWriter(new FileWriter(file));
        writeFileHeader(out);
        TableColumnModel columnModel=table.getColumnModel();
        openTableHeader(out);
        ResultSetTableModel tableModel=(ResultSetTableModel) table.getModel();
        for (int i=0; i<columnModel.getColumnCount(); i++)
        {
            TableColumn column=columnModel.getColumn(i);
            int columnIndex=column.getModelIndex();
            writeTableHeader(out, tableModel.getColumnName(columnIndex));
        }
        closeTableHeader(out);
        for (int j=0; j<tableModel.getRowCount(); j++)
        {
            openTableRow(out);
            for (int i=0; i<columnModel.getColumnCount(); i++)
            {
                TableColumn column=columnModel.getColumn(i);
                int columnIndex=column.getModelIndex();
                Object cellValue=tableModel.getValueAt(j, columnIndex);
				TableCellRenderer cellRenderer=table.getCellRenderer(j, columnIndex);
				Component component=cellRenderer.getTableCellRendererComponent(table, cellValue, false, false, j, columnIndex);
				int alignment=SwingConstants.LEFT;
				if (component instanceof JLabel)
				{
					JLabel label=(JLabel)component;
					alignment=label.getHorizontalAlignment();
					cellValue=label.getText();
				}
				writeTableCell(out, tableModel.getColumnName(columnIndex), cellValue, alignment);
            }
            closeTableRow(out);
        }
        writeFileFooter(out);
        out.close();
    }

    protected abstract void writeFileHeader(PrintWriter out);

    protected abstract void writeFileFooter(PrintWriter out);

    protected abstract void openTableHeader(PrintWriter out);

    protected abstract void closeTableHeader(PrintWriter out);

    protected abstract void writeTableHeader(PrintWriter out, String name);

    protected abstract void openTableRow(PrintWriter out);

    protected abstract void closeTableRow(PrintWriter out);

    protected abstract void writeTableCell(PrintWriter out, String columnName, Object renderedValue, int alignment);
}
