/*
 * Copyright (C) 2002-2003 Stefan Stiller
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.kiwisoft.db.export;

import java.io.PrintWriter;
import javax.swing.filechooser.FileFilter;

import com.kiwisoft.utils.RegularFileFilter;
import com.kiwisoft.utils.xml.XMLUtils;

/**
 * @author Stefan Stiller
 * @version $Revision: 1.2 $, $Date: 2004/10/26 17:49:37 $
 */
public class XMLExporter extends AbstractExporter
{
    private static Exporter instance;

    public static Exporter getInstance()
    {
        if (instance==null) instance=new XMLExporter();
        return instance;
    }

    private XMLExporter()
    {
    }

    public String getName()
    {
        return "XML";
    }

    public String getIcon()
    {
        return "xmlFile";
    }

    public FileFilter getFileFilter()
    {
        return new RegularFileFilter("*.xml", "XML Files");
    }

    protected void writeFileHeader(PrintWriter out)
    {
        out.println("<?xml version=\"1.0\"?>");
        out.println("<table>");
    }

    protected void writeFileFooter(PrintWriter out)
    {
        out.println("</table>");
    }

    protected void openTableHeader(PrintWriter out)
    {
    }

    protected void closeTableHeader(PrintWriter out)
    {
    }

    protected void writeTableHeader(PrintWriter out, String name)
    {
    }

    protected void openTableRow(PrintWriter out)
    {
        out.println("\t<row>");
    }

    protected void closeTableRow(PrintWriter out)
    {
        out.println("\t</row>");
    }

    protected void writeTableCell(PrintWriter out, String columnName, Object cellValue, int alignment)
    {
        String cellText=XMLUtils.toXMLString(String.valueOf(cellValue));
        out.println("\t\t<"+columnName+">"+cellText+"</"+columnName+">");
    }

}
