/*
 * Copyright (C) 2002-2003 Stefan Stiller
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.kiwisoft.sqlPlugin.config;

import org.jdom.Element;

import com.intellij.openapi.util.InvalidDataException;
import com.intellij.openapi.util.JDOMExternalizable;
import com.intellij.openapi.util.WriteExternalException;

import com.kiwisoft.utils.Utils;

/**
 * @author Stefan Stiller
 * @version $Revision: 1.1 $, $Date: 2004/10/08 20:41:14 $
 */
public class ExportConfiguration implements JDOMExternalizable
{
	ExportConfiguration()
	{
	}

	private HTMLExportConfiguration html;

	public HTMLExportConfiguration getHTML()
	{
		if (html==null) html=new HTMLExportConfiguration();
		return html;
	}

    private CSVExportConfiguration csv;

	public CSVExportConfiguration getCSV()
	{
		if (csv==null) csv=new CSVExportConfiguration();
		return csv;
	}

	private String path;

	public String getPath()
	{
		return path;
	}

	public void setPath(String path)
	{
		this.path=path;
	}

	public void readExternal(Element element) throws InvalidDataException
	{
		Element htmlElement=element.getChild("html");
		if (htmlElement!=null) getHTML().readExternal(htmlElement);

		Element csvElement=element.getChild("csv");
		if (csvElement!=null) getCSV().readExternal(csvElement);

		setPath(element.getAttributeValue("path"));
	}

	public void writeExternal(Element element) throws WriteExternalException
	{
		Utils.setValue(element, "path", getPath());

		Element htmlElement=new Element("html");
		element.addContent(htmlElement);
		getHTML().writeExternal(htmlElement);

		Element csvElement=new Element("csv");
		element.addContent(csvElement);
		getCSV().writeExternal(csvElement);
	}
}
