/*
 * Copyright (C) 2002-2003 Stefan Stiller
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.kiwisoft.sqlPlugin.settings;

import java.awt.event.ActionEvent;
import javax.swing.*;

import com.intellij.openapi.project.Project;
import com.kiwisoft.utils.idea.DialogStub;
import com.kiwisoft.utils.idea.DialogWrapper;

/**
 * @author Stefan Stiller
 * @version $Revision: 1.1 $, $Date: 2004/07/21 20:39:09 $
 */
public class GlobalSettingsDialogStub implements DialogStub
{
    private Project project;
    private DialogWrapper dialogWrapper;

    private JTabbedPane pnlTabs;
    private ConnectionPropertiesPanel pnlConnections;
    private ResultPropertiesPanel pnlResult;
	private MiscPropertiesPanel pnlMisc;
	private TemplateSettingsPanel pnlTemplates;

    public GlobalSettingsDialogStub(Project project)
    {
        this.project=project;
        initializeComponents();
    }

    public void setDialogWrapper(DialogWrapper dialogWrapper)
    {
        this.dialogWrapper=dialogWrapper;
    }

    private void initializeComponents()
    {
        pnlConnections=new ConnectionPropertiesPanel(project);
	    pnlResult=new ResultPropertiesPanel(project);
		pnlMisc=new MiscPropertiesPanel(project);
		pnlTemplates=new TemplateSettingsPanel(project);

        pnlTabs=new JTabbedPane();
        pnlTabs.addTab("Connections", pnlConnections);
		pnlTabs.addTab("Result", pnlResult);
	    pnlTabs.addTab("Miscellaneous", pnlMisc);
	    pnlTabs.addTab("Templates", pnlTemplates);
    }

	public JComponent getPreferredFocusedComponent()
	{
		return null;
	}

    public String getTitle()
    {
        return "Properties";
    }

    public JComponent getContentPanel()
    {
        return pnlTabs;
    }

    public void dispose()
    {
    }

    public Action[] getActions()
    {
        return new Action[]{new ApplyAction(true), new CancelAction()};
    }

    private class ApplyAction extends AbstractAction
    {
        public ApplyAction(boolean defaultAction)
        {
            super("Ok");
	        if (defaultAction) putValue(DEFAULT_ACTION, Boolean.TRUE);
        }

        public void actionPerformed(ActionEvent e)
        {
            if (!pnlConnections.canApply())
            {
	            pnlTabs.setSelectedComponent(pnlConnections);
	            return;
            }
	        if (!pnlResult.canApply())
	        {
		        pnlTabs.setSelectedComponent(pnlResult);
		        return;
            }
			if (!pnlMisc.canApply())
			{
				pnlTabs.setSelectedComponent(pnlMisc);
				return;
			}
			if (!pnlTemplates.canApply())
			{
				pnlTabs.setSelectedComponent(pnlTemplates);
				return;
			}
			try
			{
				pnlConnections.apply();
				pnlResult.apply();
				pnlMisc.apply();
				pnlTemplates.apply();
			}
			catch (Exception e1)
			{
				e1.printStackTrace();
				JOptionPane.showMessageDialog(pnlTabs, e1.getMessage(), "Exception", JOptionPane.ERROR_MESSAGE);
			}
			dialogWrapper.dispose();
        }
    }

    private class CancelAction extends AbstractAction
    {
        public CancelAction()
        {
            super("Cancel");
        }

        public void actionPerformed(ActionEvent e)
        {
            dialogWrapper.dispose();
        }
    }

}